@@ -1,3 +1,4 @@
+import html
 import inspect
 import multiprocessing as mp
 import re
@@ -44,10 +45,10 @@ def yamlDump(data, stream):
   return dumper.dump(data, stream)
 
 
-def mproc_apply(func, iterLst, descr='', iterArgPos=0, extraArgs=(), showProgress=True, applyAsync=True, total=None, pool=None):
-  if pool is None:
-    pool = mp.Pool()
-
+def mproc_apply(func, iterLst, descr='', iterArgPos=0,
+                extraArgs=(), showProgress=True, applyAsync=True,
+                total=None, pool=None,
+                debug=False):
   if total is None:
     try:
       total = len(iterLst)
@@ -55,37 +56,44 @@ def mproc_apply(func, iterLst, descr='', iterArgPos=0, extraArgs=(), showProgres
       total = None
 
   callback = None
-  if showProgress:
+  if showProgress and applyAsync and not debug:
     progBar = tqdm(total=total, desc=descr)
     def updateProgBar(*_):
       progBar.update()
     callback = updateProgBar
+  elif showProgress:
+    iterLst = tqdm(iterLst, total=total)
 
   pre_results = []
   errs = {}
-  def errCallback(_ii, ex):
-    errs[_ii] = str(ex)
+  def errCallback(fnArgs, ex):
+    errs[fnArgs[iterArgPos]] = str(ex)
 
-  iterable = enumerate(iterLst)
-  if applyAsync:
-    applyFunc = partial(pool.apply_async, callback=callback, error_callback=lambda ex: errCallback(ii, ex))
+  if debug:
+    def applyFunc(func_, args):
+      return func_(*args)
   else:
-    if showProgress:
-      iterable = tqdm(iterable, total=total)
-    applyFunc = pool.apply
+    if pool is None:
+      pool = mp.Pool()
+    if applyAsync:
+      def applyFunc(func_, args):
+        return pool.apply_async(func_, args, callback=callback, error_callback=lambda ex: errCallback(args, ex))
+    else:
+      applyFunc = pool.apply
 
   extraArgs = tuple(extraArgs)
-  for ii, el in iterable:
+  for el in iterLst:
     curArgs = extraArgs[:iterArgPos]+(el,)+extraArgs[iterArgPos:]
     pre_results.append(applyFunc(func, curArgs))
-  pool.close()
-  pool.join()
+  if not debug:
+    pool.close()
+    pool.join()
   if len(errs) > 0:
     msg = f'The following errors occurred at the specified list indices:\n'
     for k, v in errs.items():
       msg += f'{k}: {v}\n'
     warn(msg)
-  if applyAsync:
+  if applyAsync and not debug:
     return [res.get() for res in pre_results]
   else:
     return pre_results
@@ -164,8 +172,8 @@ def makeExceptionsShowDialogs(win: QtWidgets.QMainWindow,
       app.exit(1)
       app.processEvents()
       raise
-    msgWithTrace = ''.join(format_exception(etype, evalue, tb))
-    msgWithoutTrace = str(evalue)
+    msgWithTrace = html.escape(''.join(format_exception(etype, evalue, tb)))
+    msgWithoutTrace = html.escape(str(evalue))
     dlg = ScrollableErrorDialog(win, notCritical=issubclass(etype, nonCritErrs),
                                 msgWithTrace=msgWithTrace, msgWithoutTrace=msgWithoutTrace)
     dlg.show()
