@@ -172,7 +172,9 @@ class PopupLineEditorParameterItem(parameterTypes.WidgetParameterItem):
     super().__init__(param, depth)
 
   def makeWidget(self):
-    editor = PopupLineEditor(model=self.model, clearOnComplete=False)
+    opts = self.param.opts
+    editor = PopupLineEditor(model=self.model, clearOnComplete=False, forceMatch=opts.get('forceMatch', True),
+                             validateCase=opts.get('validateCase', False))
     editor.setValue = editor.setText
     editor.value = editor.text
     editor.sigChanged = editor.editingFinished
