@@ -44,7 +44,10 @@ def _mkProcParam(stage: ProcessStage):
   return {'name': stage.name, 'type': 'procgroup', 'process': stage, 'enabled': not stage.disabled}
 
 def atomicRunWrapper(proc: AtomicProcess, param: Parameter):
-  param.sigValueChanged.connect(lambda p, val: proc.input.update(**{param.name(): val}))
+  def onChange(p, val):
+    proc.input.update(**{param.name(): val})
+    proc.result = None
+  param.sigValueChanged.connect(onChange)
 
 @singledispatch
 def addStageToParam(stage: ProcessStage, parentParam: Parameter, **kwargs):
