@@ -723,6 +723,7 @@ class MaskCompositor(ImageViewer):
     # Create properties
     # -----
     self.legend = CompositorLegend(offset=(5,5), horSpacing=5, brush='ccce', pen='k')
+    self.legend.setFlag(self.legend.ItemIgnoresTransformations, False)
 
     self.recordDf = pd.DataFrame(columns=['name', 'item', 'scatter', 'opacity']).set_index('name')
 
@@ -949,9 +950,12 @@ class MaskCompositor(ImageViewer):
         item.paint(painter)
     painter.setOpacity(1.0)
 
+    tRect: QtCore.QRectF = self.legend.mapRectToItem(self.imgItem, self.legend.rect())
     if cropToViewbox:
       maxBnd = np.array(self.image.shape[:2][::-1]).reshape(-1,1) - 1
       vRange = np.array(self.viewbox.viewRange()).astype(int)
+      tRect.setX(tRect.x() - vRange[0,0])
+      tRect.setY(tRect.y() - vRange[1,0])
       vRange = np.clip(vRange, 0, maxBnd)
       # Convert range to topleft->bottomright
       pts = QtCore.QPoint(*vRange[:,0]), QtCore.QPoint(*vRange[:,1])
@@ -973,24 +977,12 @@ class MaskCompositor(ImageViewer):
     return saveImg
 
 
-  def _paintLegend(self, painter: QtGui.QPainter, floatLegend=False):
+  def _paintLegend(self, painter: QtGui.QPainter, targetRect: QtCore.QRectF):
     oldPos = self.legend.pos()
     try:
       exportScene = GraphicsScene(parent=None)
-      oldScale = max(np.clip(0.5/np.array(self.imgItem.pixelSize()), 1, np.inf))
       exportScene.addItem(self.legend)
-      self.legend.setScale(oldScale)
-      # Legend does not scale itself, handle this
-      painter.save()
-      if floatLegend:
-        viewPos = self.viewbox.viewRect()
-        viewX = max(viewPos.x(), 0)
-        viewY = max(viewPos.y(), 0)
-        imPos = self.legend.mapRectToItem(self.imgItem, self.legend.rect())
-        painter.translate(int(imPos.x() - viewX), int(imPos.y() - viewY))
-      exportScene.render(painter)
-      self.legend.setScale(1/oldScale)
-      painter.restore()
+      exportScene.render(painter, targetRect)
     finally:
       self.legend.setParentItem(self.plotItem)
       self.legend.autoAnchor(oldPos, relative=False)
